import { DeptVO } from './../dept/types';
import { RoleVO } from '@/api/system/role/types';
import request from '@/utils/request';
import { AxiosPromise } from 'axios';
import {
  UserForm,
  UserQuery,
  UserVO,
  UserInfoVO,
  PlanForm,
  PlanVO,
  PlanQuery,
  PlanInfoVO,
  DrillForm,
  FetchDrillResponse,
  DrillQuery,
  DrillInfoVO,
  ResponseForm,
  ResponseVO,
  ResponseQuery,
  ResponseInfoVO,
  AddUserParams
} from './types';
import { parseStrEmpty } from '@/utils/ruoyi';

/**
 * 查询用户列表
 * @param query
 */
export const listUser = (query): AxiosPromise<UserVO[]> => {
  return request({
    url: '/system/user/list',
    method: 'get',
    params: query
  });
};

export const listPlan = (query: PlanQuery): AxiosPromise<PlanVO[]> => {
  return request({
    url: '/system/user/list',
    method: 'get',
    params: query
  });
};
export const listDrill = (params: DrillForm): AxiosPromise<FetchDrillResponse> => {
  return request({
    url: '/api/emergency_plan/drill/list',
    method: 'get',
    params: {
      page: params.pageNum, // 分页参数中的页码
      page_size: params.pageSize, // 分页参数中的每页大小
      planNum: params.planId // 预案编号
    }
  });
};
export const listResponse = (query: DrillQuery): AxiosPromise<ResponseVO[]> => {
  return request({
    url: '/system/user/list',
    method: 'get',
    params: query
  });
};
/**
 * 通过用户ids查询用户
 * @param userIds
 */
export const optionSelect = (userIds: (number | string)[]): AxiosPromise<UserVO[]> => {
  return request({
    url: '/system/user/optionselect?userIds=' + userIds,
    method: 'get'
  });
};

/**
 * 获取培训详情
 * @param userId
 */
export const getUser = (userId?: string | number): AxiosPromise<UserInfoVO> => {
  return request({
    url: '/api/emergency_plan/training/create',
    method: 'post',
    params: {
      theme: params.theme, // 培训主题
      unitName: params.unitName, // 培训单位
      address: params.address, // 培训地点
      startTime: params.startTime, // 开始时间
      endTime: params.endTime, // 结束时间
      peopleNum: params.peopleNum, // 参与人数
      Content: params.Content, // 培训内容
      trainingWay: params.trainingWay // 培训方式
    }
  });
};
/**
 * 获取预案详情
 * @param planId
 */
export const getPlan = (planId?: string | number): AxiosPromise<PlanInfoVO> => {
  return request({
    url: '/system/user/' + parseStrEmpty(planId),
    method: 'get'
  });
};
/**
 * 获取预案详情
 * @param drillId
 */
export const getDrill = (drillId?: string | number): AxiosPromise<DrillInfoVO> => {
  return request({
    url: '/system/user/' + parseStrEmpty(drillId),
    method: 'get'
  });
};
/**
 * 获取响应详情
 * @param drillId
 */
export const getResponse = (drillId?: string | number): AxiosPromise<ResponseInfoVO> => {
  return request({
    url: '/system/user/' + parseStrEmpty(drillId),
    method: 'get'
  });
};
/**
 * 新增培训
 */
export const addUser = (data: AddUserParams) => {
  return request({
    url: '/api/emergency_plan/training/create',
    method: 'post',
    data: data
  });
};
/**
 * 新增预案
 */
export const addPlan = (data: PlanForm) => {
  return request({
    url: '/system/user',
    method: 'post',
    data: data
  });
};
/**
 * 新增演练
 */
export const addDrill = (data: DrillForm) => {
  return request({
    url: '/system/user',
    method: 'post',
    data: data
  });
};

/**
 * 修改培训
 */
export const updateUser = (data: AddUserParams) => {
  return request({
    url: '/api/emergency_plan/training/create',
    method: 'post',
    data: data
  });
};
/**
 * 修改预案
 */
export const updatePlan = (data: PlanForm) => {
  return request({
    url: '/system/user',
    method: 'put',
    data: data
  });
};
/**
 * 修改演练
 */
export const updateDrill = (data: DrillForm) => {
  return request({
    url: '/system/user',
    method: 'put',
    data: data
  });
};

/**
 * 删除用户
 * @param userId 用户ID
 */
export const delUser = (userId: Array<string | number> | string | number) => {
  return request({
    url: '/system/user/' + userId,
    method: 'delete'
  });
};
/**
 * 删除预案
 * @param planId 用户ID
 */
export const delPlan = (planId: Array<string | number> | string | number) => {
  return request({
    url: '/system/user/' + planId,
    method: 'delete'
  });
};
/**
 * 删除演练
 * @param planId 用户ID
 */
export const delDrill = (drillId: Array<string | number> | string | number) => {
  return request({
    url: '/system/user/' + drillId,
    method: 'delete'
  });
};

/**
 * 用户密码重置
 * @param userId 用户ID
 * @param password 密码
 */
export const resetUserPwd = (userId: string | number, password: string) => {
  const data = {
    userId,
    password
  };
  return request({
    url: '/system/user/resetPwd',
    method: 'put',
    headers: {
      isEncrypt: true,
      repeatSubmit: false
    },
    data: data
  });
};

/**
 * 用户状态修改
 * @param userId 用户ID
 * @param status 用户状态
 */
export const changeUserStatus = (userId: number | string, status: string) => {
  const data = {
    userId,
    status
  };
  return request({
    url: '/system/user/changeStatus',
    method: 'put',
    data: data
  });
};

/**
 * 查询用户个人信息
 */
export const getUserProfile = (): AxiosPromise<UserInfoVO> => {
  return request({
    url: '/system/user/profile',
    method: 'get'
  });
};

/**
 * 修改用户个人信息
 * @param data 用户信息
 */
export const updateUserProfile = (data: UserForm) => {
  return request({
    url: '/system/user/profile',
    method: 'put',
    data: data
  });
};

/**
 * 用户密码重置
 * @param oldPassword 旧密码
 * @param newPassword 新密码
 */
export const updateUserPwd = (oldPassword: string, newPassword: string) => {
  const data = {
    oldPassword,
    newPassword
  };
  return request({
    url: '/system/user/profile/updatePwd',
    method: 'put',
    headers: {
      isEncrypt: true,
      repeatSubmit: false
    },
    data: data
  });
};

/**
 * 用户头像上传
 * @param data 头像文件
 */
export const uploadAvatar = (data: FormData) => {
  return request({
    url: '/system/user/profile/avatar',
    method: 'post',
    data: data
  });
};

/**
 * 查询授权角色
 * @param userId 用户ID
 */
export const getAuthRole = (userId: string | number): AxiosPromise<{ user: UserVO; roles: RoleVO[] }> => {
  return request({
    url: '/system/user/authRole/' + userId,
    method: 'get'
  });
};

/**
 * 保存授权角色
 * @param data 用户ID
 */
export const updateAuthRole = (data: { userId: string; roleIds: string }) => {
  return request({
    url: '/system/user/authRole',
    method: 'put',
    params: data
  });
};

/**
 * 查询当前部门的所有用户信息
 * @param deptId
 */
export const listUserByDeptId = (deptId: string | number): AxiosPromise<UserVO[]> => {
  return request({
    url: '/system/user/list/dept/' + deptId,
    method: 'get'
  });
};

/**
 * 查询部门下拉树结构
 */
export const deptTreeSelect = (): AxiosPromise<DeptVO[]> => {
  return request({
    url: '/system/user/deptTree',
    method: 'get'
  });
};

export default {
  listUser,
  listPlan,
  listDrill,
  listResponse,
  getUser,
  getPlan,
  getDrill,
  getResponse,
  optionSelect,
  addUser,
  addPlan,
  addDrill,
  updateUser,
  updatePlan,
  updateDrill,
  delUser,
  delPlan,
  delDrill,
  resetUserPwd,
  changeUserStatus,
  getUserProfile,
  updateUserProfile,
  updateUserPwd,
  uploadAvatar,
  getAuthRole,
  updateAuthRole,
  deptTreeSelect,
  listUserByDeptId
};
